@@ -28,18 +28,16 @@ class NeedleWebElement(WebElement):
         Returns a dictionary containing, in pixels, the element's ``width`` and
         ``height``, and it's ``left`` and ``top`` position relative to the document.
         """
+        self._parent.load_jquery()
         return self._parent.execute_script("""
-            var e = arguments[0];
+            var e = $(arguments[0]);
+            var offset = e.offset();
             var dimensions = {
-                'width': e.offsetWidth,
-                'height': e.offsetHeight,
-                'left': 0,
-                'top': 0
+                'width': e.outerWidth(),
+                'height': e.outerHeight(),
+                'left': Math.floor(offset.left),
+                'top': Math.floor(offset.top)
             };
-            do {
-                dimensions['left'] += e.offsetLeft;
-                dimensions['top'] += e.offsetTop;
-            } while (e = e.offsetParent)
             return dimensions;
         """, self)
 
@@ -89,12 +87,13 @@ class NeedleWebDriverMixin(object):
         Loads jQuery 1.5 onto the current page so calls to
         :py:meth:`execute_script` have access to it.
         """
-        # Bug in 1.5.1 means we can't load on data URL pages.
-        # Should be fixed in 1.5.2
-        # https://github.com/jquery/jquery/pull/269
-        self.execute_script(open(
-            os.path.join(self._get_js_path(), 'jquery-1.5.min.js')
-        ).read() + '\nreturn "";')
+        if (self.execute_script('return typeof(jQuery)') == 'undefined'):
+            # Bug in 1.5.1 means we can't load on data URL pages.
+            # Should be fixed in 1.5.2
+            # https://github.com/jquery/jquery/pull/269
+            self.execute_script(open(
+                os.path.join(self._get_js_path(), 'jquery-1.5.min.js')
+            ).read() + '\nreturn "";')
 
     def _get_js_path(self):
         return os.path.join(os.path.dirname(os.path.abspath(__file__)), 'js')
